"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.assertConfigValueType = exports.getConfigSrc = exports.getPageConfig = exports.getConfigValue2 = exports.getConfigValue = void 0;
const utils_js_1 = require("../utils.js");
const picocolors_1 = __importDefault(require("@brillout/picocolors"));
const getExportPath_js_1 = require("./getExportPath.js");
function getConfigValue(pageConfig, configName, type) {
    const configValue = getConfigValue2(pageConfig, configName, type);
    if (!configValue)
        return null;
    return configValue.value;
}
exports.getConfigValue = getConfigValue;
// prettier-ignore
function getConfigValue2(pageConfig, configName, type) {
    const configValue = pageConfig.configValues ? pageConfig.configValues[configName] : pageConfig.configValueSources[configName]?.[0];
    if (!configValue)
        return null;
    const { value, definedAt } = configValue;
    if (isNullish(value))
        return null;
    assertConfigValueType({ value, definedAt }, type);
    return { value, definedAt };
}
exports.getConfigValue2 = getConfigValue2;
function isNullish(configValue) {
    return (configValue === null ||
        // TODO: stop allowing users to set undefined and, instead, force them to use `null`?
        configValue === undefined);
}
function getPageConfig(pageId, pageConfigs) {
    const pageConfig = pageConfigs.find((p) => p.pageId === pageId);
    (0, utils_js_1.assert)(pageConfigs.length > 0);
    (0, utils_js_1.assert)(pageConfig);
    return pageConfig;
}
exports.getPageConfig = getPageConfig;
function assertConfigValueType({ value, definedAt }, type) {
    if (type === undefined)
        return;
    (0, utils_js_1.assert)(value !== null);
    const configSrc = getConfigSrc({ definedAt });
    const typeActual = typeof value;
    (0, utils_js_1.assertUsage)(typeActual === type, `${configSrc} has an invalid type ${picocolors_1.default.cyan(typeActual)}: is should be a ${picocolors_1.default.cyan(type)} instead`);
}
exports.assertConfigValueType = assertConfigValueType;
// TODO: rename to getValueSrc()
function getConfigSrc({ definedAt }, append) {
    const { filePath, fileExportPath } = definedAt;
    let configSrc = filePath;
    const exportPath = (0, getExportPath_js_1.getExportPath)(fileExportPath);
    if (exportPath) {
        configSrc = `${configSrc} > ${picocolors_1.default.cyan(exportPath)}`;
    }
    if (append) {
        configSrc = `${configSrc} > (${picocolors_1.default.blue(append)})`;
    }
    return configSrc;
}
exports.getConfigSrc = getConfigSrc;
