export { getConfigValue };
export { getConfigValue2 };
export { getPageConfig };
export { getConfigSrc };
export { assertConfigValueType };
import { assert, assertUsage } from '../utils.js';
import pc from '@brillout/picocolors';
import { getExportPath } from './getExportPath.js';
function getConfigValue(pageConfig, configName, type) {
    const configValue = getConfigValue2(pageConfig, configName, type);
    if (!configValue)
        return null;
    return configValue.value;
}
// prettier-ignore
function getConfigValue2(pageConfig, configName, type) {
    const configValue = pageConfig.configValues ? pageConfig.configValues[configName] : pageConfig.configValueSources[configName]?.[0];
    if (!configValue)
        return null;
    const { value, definedAt } = configValue;
    if (isNullish(value))
        return null;
    assertConfigValueType({ value, definedAt }, type);
    return { value, definedAt };
}
function isNullish(configValue) {
    return (configValue === null ||
        // TODO: stop allowing users to set undefined and, instead, force them to use `null`?
        configValue === undefined);
}
function getPageConfig(pageId, pageConfigs) {
    const pageConfig = pageConfigs.find((p) => p.pageId === pageId);
    assert(pageConfigs.length > 0);
    assert(pageConfig);
    return pageConfig;
}
function assertConfigValueType({ value, definedAt }, type) {
    if (type === undefined)
        return;
    assert(value !== null);
    const configSrc = getConfigSrc({ definedAt });
    const typeActual = typeof value;
    assertUsage(typeActual === type, `${configSrc} has an invalid type ${pc.cyan(typeActual)}: is should be a ${pc.cyan(type)} instead`);
}
// TODO: rename to getValueSrc()
function getConfigSrc({ definedAt }, append) {
    const { filePath, fileExportPath } = definedAt;
    let configSrc = filePath;
    const exportPath = getExportPath(fileExportPath);
    if (exportPath) {
        configSrc = `${configSrc} > ${pc.cyan(exportPath)}`;
    }
    if (append) {
        configSrc = `${configSrc} > (${pc.blue(append)})`;
    }
    return configSrc;
}
